# Tests by default. No tests: rpm -ba --define 'dotests 0' *.spec

%{!?dotests: %define dotests 0}

%global __tar /opt/freeware/bin/tar
%global _libdir64 %{_prefix}/lib64
%global name xgboost
%global version 1.7.6
%global release 1

#python releated configs
%global py_major 3.9
%global py_minor 18

%global python_major python%{py_major}

%global python3_sitearch %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(0))")
%global python3_sitearch64 %(%{python_major} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")

Name:           %{name}
Version:        %{version}
Release:        1
Summary:        eXtreme Gradient Boosting
License:        Apache-2.0
URL:            https://xgboost.ai
Source0:        https://github.com/dmlc/xgboost/archive/refs/tags/v%{version}.tar.gz
Source1:        https://github.com/dmlc/dmlc-core/archive/refs/tags/v0.5.tar.gz
Source2:        https://github.com/NVlabs/cub/archive/refs/tags/2.1.0.tar.gz
Source3:        https://github.com/rapidsai/gputreeshap/archive/refs/tags/v22.02.00.tar.gz

Patch0:         xgboost-1.7.6-aix-support.patch
Patch1:         xgboost-1.7.6-test-fix.patch

BuildRequires:  cmake >= 3.26.4
BuildRequires:  gtest-devel >= 1.14.0

%if %{toolchain} == "gcc"
Requires: 	libstdc++ >= 10
Requires: 	libgcc >= 10
%endif
Requires: 	libgomp >= 10

%description
XGBoost is an optimized distributed gradient boosting library designed to be highly efficient, flexible and portable. 
It implements machine learning algorithms under the Gradient Boosting framework. 
XGBoost provides a parallel tree boosting (also known as GBDT, GBM) that solve many data science problems in a fast and accurate way.

%package devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}

%description devel
Development headers for %{name}.

%package python3
Summary:        xgboost Python Package
Group:          Development/Libraries/Python

BuildRequires:  %{python_major}-devel >= %{py_major}.%{py_minor}
BuildRequires:  %{python_major}-setuptools >= 65.2.0
Requires:       %{name} = %{version}-%{release}
Requires:       %{python_major} >= %{py_major}.%{py_minor}
Requires:       %{python_major}-numpy >= 1.26.2
Requires:       %{python_major}-scipy >= 1.11.2
%if %{toolchain} == "gcc"
Requires: 	libstdc++ >= 10
Requires: 	libgcc >= 10
%endif
Requires: 	libgomp >= 10

%description python3
This package contains the Python 3 bindings for XGBoost.

%prep
%setup -n  xgboost-%{version}
%patch0 -p1
%patch1 -p1
%{__tar} -xvf %{SOURCE1}  --strip 1 -C dmlc-core
%{__tar} -xvf %{SOURCE2}  --strip 1 -C cub 
%{__tar} -xvf %{SOURCE3}  --strip 1 -C gputreeshap

%build
#64bit Build only
export OBJECT_MODE=64
export CC="%{__cc__} -maix64 -pthread -maltivec -mvsx "
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include "
export CXX="%{__cxx__} -maix64 -pthread -maltivec -mvsx "
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include"
export LDFLAGS="-L/opt/freeware/lib/pthread -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib"

cmake . -B build \
  -DGOOGLE_TEST=ON\
  -DBUILD_SHARED_LIBS=ON \
  -DCMAKE_INSTALL_PREFIX=%{_prefix}

cmake --build build -j 4

%install
ulimit -m unlimited
ulimit -d unlimited
export DESTDIR=$RPM_BUILD_ROOT
cmake  --install build
/usr/bin/strip -X64 $RPM_BUILD_ROOT%{_prefix}/bin/xgboost

#python installation
export OBJECT_MODE=64
export CC="%{__cc__} -maix64 -pthread -maltivec -mvsx "
export CFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include "
export CXX="%{_cxx__} -maix64 -pthread -maltivec -mvsx "
export CXXFLAGS="-I/opt/freeware/include -fPIC -O2 -I/usr/include "
export LDFLAGS="-L/opt/freeware/lib/pthread -L/opt/freeware/lib64 -L/opt/freeware/lib -L/usr/lib"

cd python-package
%{python_major} -m pip install . --root %{buildroot} -vvv -I --no-deps 
cd ..

%check
export LIBPATH=/opt/freeware/lib/pthread:/opt/freeware/lib64:/opt/freeware/lib
cd build
ulimit -m unlimited;ulimit -d unlimited;./testxgboost || true

%files
%defattr(-,root,system,-)
%doc README.md LICENSE NEWS.md
%{_libdir}/*.a
%{_bindir}/*

%files devel
%defattr(-,root,system,-)
%{_includedir}/xgboost/
%{_includedir}/dmlc/
%{_libdir}/cmake/xgboost
%{_libdir}/pkgconfig/xgboost.pc

%files python3
%defattr(-,root,system,-)
%doc README.md LICENSE NEWS.md
%{python3_sitearch64}/*

%changelog
* Mon May 06 2024 Ranjit Ranjan <ranjit.ranjan@ibm.com> - 1.7.6-1
- Port on AIX.
